@@ -1,6 +1,6 @@
 /* client_session.c
  *
- * $Id: client_session.c,v 1.2 2000/11/26 17:51:06 nisse Exp $
+ * $Id: client_session.c,v 1.4 2001/03/12 22:20:53 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -51,12 +51,18 @@
 */
 
 /* Callback used when the server sends us eof */
+
+/* FIXME: Perhaps unify with server_session.c:do_eof */
 static void
 do_client_session_eof(struct ssh_channel *c)
 {
   CAST(client_session_channel, session, c);
-  
+
+  close_fd(session->out);
+  close_fd(session->err);
+#if 0
   close_fd(session->in);
+#endif
 }  
 
 static void
