@@ -2,7 +2,7 @@
  *
  * Simple mark&sweep garbage collector.
  *
- * $Id: gc.c,v 1.14 2000/10/31 22:08:37 nisse Exp $ */
+ * $Id: gc.c,v 1.15 2001/02/25 22:38:18 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -158,7 +158,7 @@ void gc_register(struct lsh_object *o)
 /* NOTE: If the object is close to the start of the object list, it is
  * deallocated and forgotten immedietely. If the object is not found,
  * we don't search the entire list, but instead defer deallocation to
- * gc_sweep(). */
+ * gc_sweep. */
 void gc_kill(struct lsh_object *o)
 {
   sanity_check_object_list();
@@ -194,7 +194,7 @@ void gc_kill(struct lsh_object *o)
   else
     {
 #if 0
-      debug("gc_kill:   Deferring deallocation to gc_sweep()\n");
+      debug("gc_kill:   Deferring deallocation to gc_sweep\n");
 #endif
     }
   
