@@ -1,6 +1,6 @@
 /* handshake.c
  *
- * $Id: handshake.c,v 1.2 2000/11/26 23:25:52 nisse Exp $
+ * $Id: handshake.c,v 1.3 2001/03/12 21:21:14 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -163,11 +163,7 @@ do_line(struct line_handler **h,
 		      | PEER_USERAUTH_REQUEST_KLUDGE | PEER_SEND_NO_DEBUG);
 		verbose("ssh.com 2.1.0\n");
 	      }
-	    /* FIXME: Deal with "SSH-1.99-2.2.0 Secure Shell" and
-	     * "SSH-2.0-2.2.0 Secure Shell", which should fix most or
-	     * all of the viloations of the spec. */
-	       
-#endif	    
+#endif /* DATAFELLOWS_WORKAROUNDS */ 
 	    
 	    new = 
 	      make_read_packet(
