@@ -2,7 +2,7 @@
  *
  * main proxy program.
  *
- * $Id: lsh_proxy.c,v 1.20 2000/11/26 23:25:56 nisse Exp $ */
+ * $Id: lsh_proxy.c,v 1.21 2001/02/25 22:38:19 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -467,7 +467,7 @@ do_proxy_destination(struct command *s,
       else
 	{
 	  struct exception *ex = 
-	    make_io_exception(EXC_IO, client_addr->fd, errno, "getsockname() failed");
+	    make_io_exception(EXC_IO, client_addr->fd, errno, "getsockname failed");
 
 	  EXCEPTION_RAISE(e, ex);
 	}
