@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.56 2000/11/26 23:25:59 nisse Exp $
+ * $Id: server_session.c,v 1.59 2001/03/12 21:41:15 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -126,18 +126,15 @@ do_send_adjust(struct ssh_channel *s,
     }
 }
 
+/* FIXME: Perhaps unify with client_session.c:do_client_session_eof */
 static void
 do_eof(struct ssh_channel *channel)
 {
   CAST(server_session, session, channel);
 
-  trace("server_session.c: do_eof()\n");
+  trace("server_session.c: do_eof\n");
 
   write_buffer_close(session->in->write_buffer);
-
-  if ( (channel->flags & CHANNEL_SENT_EOF)
-       && (channel->flags & CHANNEL_CLOSE_AT_EOF))
-    channel_close(channel);
 }
 
 struct ssh_channel *
@@ -191,7 +188,7 @@ do_open_session(struct channel_open *s,
 {
   CAST(open_session, self, s);
 
-  debug("server.c: do_open_session()\n");
+  debug("server.c: do_open_session\n");
 
   assert(connection->user);
   
@@ -259,25 +256,28 @@ do_exit_shell(struct exit_callback *c, int signaled,
   struct server_session *session = closure->session;
   struct ssh_channel *channel = &session->super;
   
-  trace("server_session.c: do_exit_shell()\n");
+  trace("server_session.c: do_exit_shell\n");
   
-  /* NOTE: We don't close the child's stdio here. The io-backend
-   * should notice EOF anyway, and the client should send EOF when it
-   * receives news of the process's death, unless it really wants to
-   * talk to any live grand children processes. */
+  /* NOTE: We don't close the child's stdio here. */
 
-  /* We close when we have both sent and received eof. */
-  channel->flags |= CHANNEL_CLOSE_AT_EOF;
-  
   if (!(channel->flags & CHANNEL_SENT_CLOSE))
     {
+      verbose("server_session.c: Sending %a message on channel %i\n",
+	      signaled ? ATOM_EXIT_SIGNAL : ATOM_EXIT_STATUS,
+	      channel->channel_number);
+      
       A_WRITE(channel->write,
 	      (signaled
 	       ? format_exit_signal(channel, core, value)
 	       : format_exit(channel, value)) );
 
-      if ( (channel->flags & CHANNEL_SENT_EOF)
-	   && (channel->flags & CHANNEL_RECEIVED_EOF))
+      /* We want to close the channel as soon as all stdout and stderr
+       * data has been sent. In particular, we don't wait for EOF from
+       * the client, most clients never sends that. */
+      
+      channel->flags |= (CHANNEL_NO_WAIT_FOR_EOF | CHANNEL_CLOSE_AT_EOF);
+      
+      if (channel->flags & CHANNEL_SENT_EOF)
 	{
 	  /* We have sent EOF already, so initiate close */
 	  channel_close(channel);
@@ -507,6 +507,9 @@ spawn_process(struct server_session *session,
 	      REMEMBER_RESOURCE
 		(channel->resources, &session->err->super);
 
+	    /* Don't close channel immediately at EOF, as we want to
+	     * get a chance to send exit-status or exit-signal. */
+	    session->super.flags &= ~CHANNEL_CLOSE_AT_EOF;
 	    return 1;
 	  }
 	else
@@ -583,7 +586,7 @@ spawn_process(struct server_session *session,
 	    return 0;
 	  }
       }
-    /* fork() failed */
+    /* fork failed */
     /* Close and return channel_failure */
 
     close(err[0]);
@@ -655,7 +658,7 @@ do_spawn_shell(struct channel_request *c,
 	USER_EXEC(connection->user, 1, argv, env_length, env);
 	
 	/* exec failed! */
-	verbose("server_session: exec() failed (errno = %i): %z\n",
+	verbose("server_session: exec failed (errno = %i): %z\n",
 		errno, STRERROR(errno));
 	_exit(EXIT_FAILURE);
 
@@ -671,7 +674,7 @@ do_spawn_shell(struct channel_request *c,
 #endif
       }
     case -1:
-      /* fork() failed */
+      /* fork failed */
 
       break;
     default:
@@ -772,12 +775,12 @@ do_spawn_exec(struct channel_request *c,
 	USER_EXEC(connection->user, 0, argv, env_length, env);
 	
 	/* exec failed! */
-	verbose("server_session: exec() failed (errno = %i): %z\n",
+	verbose("server_session: exec failed (errno = %i): %z\n",
 		errno, STRERROR(errno));
 	_exit(EXIT_FAILURE);
       }
     case -1:
-      /* fork() failed */
+      /* fork failed */
       lsh_string_free(command_line);
 
       break;
