@@ -2,7 +2,7 @@
  *
  * SPKI interface
  *
- * $Id: spki_commands.c,v 1.17 2001/01/24 21:25:12 nisse Exp $ */
+ * $Id: spki_commands.c,v 1.18 2001/02/25 22:38:21 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -357,7 +357,7 @@ make_spki_read_acls(struct alist *algorithms)
 {
   CAST_SUBTYPE(command, res, spki_read_acl(algorithms));
 
-  trace("make_spki_read_acl()\n");
+  trace("make_spki_read_acl\n");
   return res;
 }
 
