@@ -2,7 +2,7 @@
  *
  * Create an SRP verifier
  *
- * $Id: srp-gen.c,v 1.5 2000/11/15 17:35:27 nisse Exp $ */
+ * $Id: srp-gen.c,v 1.7 2000/11/20 20:47:51 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -27,9 +27,8 @@
 
 #include "crypto.h"
 #include "format.h"
+#include "interact.h"
 #include "io.h"
-/* For read_password() */
-#include "password.h"
 #include "randomness.h"
 #include "sexp.h"
 #include "srp.h"
@@ -65,6 +64,9 @@ const char *argp_program_bug_address = BUG_ADDRESS;
      (name srp_gen_options)
      (vars
        (backend object io_backend)
+
+       (tty object interact)
+       
        (e object exception_handler)
        (G object abstract_group)
        (H object hash_algorithm)
@@ -86,6 +88,10 @@ make_srp_gen_options(struct io_backend *backend,
   NEW(srp_gen_options, self);
 
   self->backend = backend;
+
+  /* We don't need window change tracking. */
+  self->tty = make_unix_interact(NULL);
+  
   self->e = e;
 
   self->G = make_ssh_ring_srp_1();
@@ -166,11 +172,13 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	  struct lsh_string *pw;
 	  struct lsh_string *again;
 
-	  pw = read_password(500, ssh_format("Enter new SRP password: "), 1);
+	  pw = INTERACT_READ_PASSWORD(self->tty, 500,
+				      ssh_format("Enter new SRP password: "), 1);
 	  if (!pw)
 	    argp_failure(state, EXIT_FAILURE, 0, "Aborted.");
 
-	  again = read_password(500, ssh_format("Again: "), 1);
+	  again = INTERACT_READ_PASSWORD(self->tty, 500,
+					 ssh_format("Again: "), 1);
 	  if (!again)
 	    argp_failure(state, EXIT_FAILURE, 0, "Aborted.");
 
