@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: werror.c,v 1.49 2000/10/03 21:51:16 nisse Exp $ */
+ * $Id: werror.c,v 1.50 2001/02/25 22:38:22 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -26,7 +26,10 @@
 #include "werror.h"
 
 #include "charset.h"
-#include "format.h"  /* For format_size_in_decimal() */
+
+/* For format_size_in_decimal */
+#include "format.h"
+
 #include "gc.h"
 #include "io.h"
 #include "parse.h"
